@@ -5,12 +5,15 @@ class RPCMessageType(Enum):
     STATUS = 'status'
     WARNING = 'warning'
     STARTUP = 'startup'
-    BUY = 'buy'
-    BUY_FILL = 'buy_fill'
-    BUY_CANCEL = 'buy_cancel'
-    SELL = 'sell'
-    SELL_FILL = 'sell_fill'
-    SELL_CANCEL = 'sell_cancel'
+
+    ENTRY = 'entry'
+    ENTRY_FILL = 'entry_fill'
+    ENTRY_CANCEL = 'entry_cancel'
+
+    EXIT = 'exit'
+    EXIT_FILL = 'exit_fill'
+    EXIT_CANCEL = 'exit_cancel'
+
     PROTECTION_TRIGGER = 'protection_trigger'
     PROTECTION_TRIGGER_GLOBAL = 'protection_trigger_global'
 
