@@ -71,14 +71,14 @@ class Gateio(Exchange):
                             }
         return trades
 
-    def fetch_stoploss_order(self, order_id: str, pair: str, params={}) -> Dict:
+    def fetch_stoploss_order(self, order_id: str, pair: str, params: Dict = {}) -> Dict:
         return self.fetch_order(
             order_id=order_id,
             pair=pair,
             params={'stop': True}
         )
 
-    def cancel_stoploss_order(self, order_id: str, pair: str, params={}) -> Dict:
+    def cancel_stoploss_order(self, order_id: str, pair: str, params: Dict = {}) -> Dict:
         return self.cancel_order(
             order_id=order_id,
             pair=pair,
