@@ -63,7 +63,7 @@ class CryptoToFiatConverter:
         except RequestException as request_exception:
             if "429" in str(request_exception):
                 logger.warning(
-                    "Too many requests for Coingecko API, backing off and trying again later.")
+                    "Too many requests for CoinGecko API, backing off and trying again later.")
                 # Set backoff timestamp to 60 seconds in the future
                 self._backoff = datetime.datetime.now().timestamp() + 60
                 return
@@ -86,7 +86,7 @@ class CryptoToFiatConverter:
                     return None
             else:
                 return None
-        found = [x for x in self._coinlistings if x['symbol'] == crypto_symbol]
+        found = [x for x in self._coinlistings if x['symbol'].lower() == crypto_symbol]
 
         if crypto_symbol in coingecko_mapping.keys():
             found = [x for x in self._coinlistings if x['id'] == coingecko_mapping[crypto_symbol]]
@@ -96,7 +96,7 @@ class CryptoToFiatConverter:
 
         if len(found) > 0:
             # Wrong!
-            logger.warning(f"Found multiple mappings in goingekko for {crypto_symbol}.")
+            logger.warning(f"Found multiple mappings in CoinGecko for {crypto_symbol}.")
             return None
 
     def convert_amount(self, crypto_amount: float, crypto_symbol: str, fiat_symbol: str) -> float:
@@ -160,7 +160,7 @@ class CryptoToFiatConverter:
 
     def _find_price(self, crypto_symbol: str, fiat_symbol: str) -> float:
         """
-        Call CoinGekko API to retrieve the price in the FIAT
+        Call CoinGecko API to retrieve the price in the FIAT
         :param crypto_symbol: Crypto-currency you want to convert (e.g btc)
         :param fiat_symbol: FIAT currency you want to convert to (e.g usd)
         :return: float, price of the crypto-currency in Fiat
