@@ -5,7 +5,7 @@ from unittest.mock import MagicMock
 import pytest
 from requests import RequestException
 
-from freqtrade.enums import RPCMessageType, SellType
+from freqtrade.enums import ExitType, RPCMessageType
 from freqtrade.rpc import RPC
 from freqtrade.rpc.webhook import Webhook
 from tests.conftest import get_patched_freqtradebot, log_has
@@ -15,32 +15,38 @@ def get_webhook_dict() -> dict:
     return {
         "enabled": True,
         "url": "https://maker.ifttt.com/trigger/freqtrade_test/with/key/c764udvJ5jfSlswVRukZZ2/",
-        "webhookbuy": {
+        "webhookentry": {
             "value1": "Buying {pair}",
             "value2": "limit {limit:8f}",
-            "value3": "{stake_amount:8f} {stake_currency}"
+            "value3": "{stake_amount:8f} {stake_currency}",
+            "value4": "leverage {leverage:.1f}",
+            "value5": "direction {direction}"
         },
-        "webhookbuycancel": {
+        "webhookentrycancel": {
             "value1": "Cancelling Open Buy Order for {pair}",
             "value2": "limit {limit:8f}",
-            "value3": "{stake_amount:8f} {stake_currency}"
+            "value3": "{stake_amount:8f} {stake_currency}",
+            "value4": "leverage {leverage:.1f}",
+            "value5": "direction {direction}"
         },
-        "webhookbuyfill": {
+        "webhookentryfill": {
             "value1": "Buy Order for {pair} filled",
             "value2": "at {open_rate:8f}",
-            "value3": "{stake_amount:8f} {stake_currency}"
+            "value3": "{stake_amount:8f} {stake_currency}",
+            "value4": "leverage {leverage:.1f}",
+            "value5": "direction {direction}"
         },
-        "webhooksell": {
+        "webhookexit": {
             "value1": "Selling {pair}",
             "value2": "limit {limit:8f}",
             "value3": "profit: {profit_amount:8f} {stake_currency} ({profit_ratio})"
         },
-        "webhooksellcancel": {
+        "webhookexitcancel": {
             "value1": "Cancelling Open Sell Order for {pair}",
             "value2": "limit {limit:8f}",
             "value3": "profit: {profit_amount:8f} {stake_currency} ({profit_ratio})"
         },
-        "webhooksellfill": {
+        "webhookexitfill": {
             "value1": "Sell Order for {pair} filled",
             "value2": "at {close_rate:8f}",
             "value3": ""
@@ -68,9 +74,11 @@ def test_send_msg_webhook(default_conf, mocker):
     msg_mock = MagicMock()
     mocker.patch("freqtrade.rpc.webhook.Webhook._send_msg", msg_mock)
     msg = {
-        'type': RPCMessageType.BUY,
+        'type': RPCMessageType.ENTRY,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
+        'leverage': 1.0,
+        'direction': 'Long',
         'limit': 0.005,
         'stake_amount': 0.8,
         'stake_amount_fiat': 500,
@@ -80,18 +88,51 @@ def test_send_msg_webhook(default_conf, mocker):
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhookbuy"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookentry"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhookbuy"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookentry"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhookbuy"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookentry"]["value3"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value4"] ==
+            default_conf["webhook"]["webhookentry"]["value4"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value5"] ==
+            default_conf["webhook"]["webhookentry"]["value5"].format(**msg))
+    # Test short
+    msg_mock.reset_mock()
+
+    msg = {
+        'type': RPCMessageType.ENTRY,
+        'exchange': 'Binance',
+        'pair': 'ETH/BTC',
+        'leverage': 2.0,
+        'direction': 'Short',
+        'limit': 0.005,
+        'stake_amount': 0.8,
+        'stake_amount_fiat': 500,
+        'stake_currency': 'BTC',
+        'fiat_currency': 'EUR'
+    }
+    webhook.send_msg(msg=msg)
+    assert msg_mock.call_count == 1
+    assert (msg_mock.call_args[0][0]["value1"] ==
+            default_conf["webhook"]["webhookentry"]["value1"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value2"] ==
+            default_conf["webhook"]["webhookentry"]["value2"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value3"] ==
+            default_conf["webhook"]["webhookentry"]["value3"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value4"] ==
+            default_conf["webhook"]["webhookentry"]["value4"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value5"] ==
+            default_conf["webhook"]["webhookentry"]["value5"].format(**msg))
     # Test buy cancel
     msg_mock.reset_mock()
 
     msg = {
-        'type': RPCMessageType.BUY_CANCEL,
+        'type': RPCMessageType.ENTRY_CANCEL,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
+        'leverage': 1.0,
+        'direction': 'Long',
         'limit': 0.005,
         'stake_amount': 0.8,
         'stake_amount_fiat': 500,
@@ -101,18 +142,47 @@ def test_send_msg_webhook(default_conf, mocker):
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhookbuycancel"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookentrycancel"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhookbuycancel"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookentrycancel"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhookbuycancel"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookentrycancel"]["value3"].format(**msg))
+    # Test short cancel
+    msg_mock.reset_mock()
+
+    msg = {
+        'type': RPCMessageType.ENTRY_CANCEL,
+        'exchange': 'Binance',
+        'pair': 'ETH/BTC',
+        'leverage': 2.0,
+        'direction': 'Short',
+        'limit': 0.005,
+        'stake_amount': 0.8,
+        'stake_amount_fiat': 500,
+        'stake_currency': 'BTC',
+        'fiat_currency': 'EUR'
+    }
+    webhook.send_msg(msg=msg)
+    assert msg_mock.call_count == 1
+    assert (msg_mock.call_args[0][0]["value1"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value1"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value2"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value2"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value3"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value3"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value4"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value4"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value5"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value5"].format(**msg))
     # Test buy fill
     msg_mock.reset_mock()
 
     msg = {
-        'type': RPCMessageType.BUY_FILL,
+        'type': RPCMessageType.ENTRY_FILL,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
+        'leverage': 1.0,
+        'direction': 'Long',
         'open_rate': 0.005,
         'stake_amount': 0.8,
         'stake_amount_fiat': 500,
@@ -122,15 +192,47 @@ def test_send_msg_webhook(default_conf, mocker):
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhookbuyfill"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookentryfill"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhookbuyfill"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookentryfill"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhookbuyfill"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookentryfill"]["value3"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value4"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value4"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value5"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value5"].format(**msg))
+    # Test short fill
+    msg_mock.reset_mock()
+
+    msg = {
+        'type': RPCMessageType.ENTRY_FILL,
+        'exchange': 'Binance',
+        'pair': 'ETH/BTC',
+        'leverage': 2.0,
+        'direction': 'Short',
+        'open_rate': 0.005,
+        'stake_amount': 0.8,
+        'stake_amount_fiat': 500,
+        'stake_currency': 'BTC',
+        'fiat_currency': 'EUR'
+    }
+    webhook.send_msg(msg=msg)
+    assert msg_mock.call_count == 1
+    assert (msg_mock.call_args[0][0]["value1"] ==
+            default_conf["webhook"]["webhookentryfill"]["value1"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value2"] ==
+            default_conf["webhook"]["webhookentryfill"]["value2"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value3"] ==
+            default_conf["webhook"]["webhookentryfill"]["value3"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value4"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value4"].format(**msg))
+    assert (msg_mock.call_args[0][0]["value5"] ==
+            default_conf["webhook"]["webhookentrycancel"]["value5"].format(**msg))
     # Test sell
     msg_mock.reset_mock()
+
     msg = {
-        'type': RPCMessageType.SELL,
+        'type': RPCMessageType.EXIT,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
         'gain': "profit",
@@ -142,20 +244,20 @@ def test_send_msg_webhook(default_conf, mocker):
         'profit_amount': 0.001,
         'profit_ratio': 0.20,
         'stake_currency': 'BTC',
-        'sell_reason': SellType.STOP_LOSS.value
+        'sell_reason': ExitType.STOP_LOSS.value
     }
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhooksell"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookexit"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhooksell"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookexit"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhooksell"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookexit"]["value3"].format(**msg))
     # Test sell cancel
     msg_mock.reset_mock()
     msg = {
-        'type': RPCMessageType.SELL_CANCEL,
+        'type': RPCMessageType.EXIT_CANCEL,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
         'gain': "profit",
@@ -167,20 +269,20 @@ def test_send_msg_webhook(default_conf, mocker):
         'profit_amount': 0.001,
         'profit_ratio': 0.20,
         'stake_currency': 'BTC',
-        'sell_reason': SellType.STOP_LOSS.value
+        'sell_reason': ExitType.STOP_LOSS.value
     }
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhooksellcancel"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookexitcancel"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhooksellcancel"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookexitcancel"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhooksellcancel"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookexitcancel"]["value3"].format(**msg))
     # Test Sell fill
     msg_mock.reset_mock()
     msg = {
-        'type': RPCMessageType.SELL_FILL,
+        'type': RPCMessageType.EXIT_FILL,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
         'gain': "profit",
@@ -192,16 +294,16 @@ def test_send_msg_webhook(default_conf, mocker):
         'profit_amount': 0.001,
         'profit_ratio': 0.20,
         'stake_currency': 'BTC',
-        'sell_reason': SellType.STOP_LOSS.value
+        'sell_reason': ExitType.STOP_LOSS.value
     }
     webhook.send_msg(msg=msg)
     assert msg_mock.call_count == 1
     assert (msg_mock.call_args[0][0]["value1"] ==
-            default_conf["webhook"]["webhooksellfill"]["value1"].format(**msg))
+            default_conf["webhook"]["webhookexitfill"]["value1"].format(**msg))
     assert (msg_mock.call_args[0][0]["value2"] ==
-            default_conf["webhook"]["webhooksellfill"]["value2"].format(**msg))
+            default_conf["webhook"]["webhookexitfill"]["value2"].format(**msg))
     assert (msg_mock.call_args[0][0]["value3"] ==
-            default_conf["webhook"]["webhooksellfill"]["value3"].format(**msg))
+            default_conf["webhook"]["webhookexitfill"]["value3"].format(**msg))
 
     for msgtype in [RPCMessageType.STATUS,
                     RPCMessageType.WARNING,
@@ -225,20 +327,20 @@ def test_send_msg_webhook(default_conf, mocker):
 
 def test_exception_send_msg(default_conf, mocker, caplog):
     default_conf["webhook"] = get_webhook_dict()
-    del default_conf["webhook"]["webhookbuy"]
+    del default_conf["webhook"]["webhookentry"]
 
     webhook = Webhook(RPC(get_patched_freqtradebot(mocker, default_conf)), default_conf)
-    webhook.send_msg({'type': RPCMessageType.BUY})
-    assert log_has(f"Message type '{RPCMessageType.BUY}' not configured for webhooks",
+    webhook.send_msg({'type': RPCMessageType.ENTRY})
+    assert log_has(f"Message type '{RPCMessageType.ENTRY}' not configured for webhooks",
                    caplog)
 
     default_conf["webhook"] = get_webhook_dict()
-    default_conf["webhook"]["webhookbuy"]["value1"] = "{DEADBEEF:8f}"
+    default_conf["webhook"]["webhookentry"]["value1"] = "{DEADBEEF:8f}"
     msg_mock = MagicMock()
     mocker.patch("freqtrade.rpc.webhook.Webhook._send_msg", msg_mock)
     webhook = Webhook(RPC(get_patched_freqtradebot(mocker, default_conf)), default_conf)
     msg = {
-        'type': RPCMessageType.BUY,
+        'type': RPCMessageType.ENTRY,
         'exchange': 'Binance',
         'pair': 'ETH/BTC',
         'limit': 0.005,
